==> hyde-0.8b2.tar.gz: hyde-0.8b2/hyde/tests/ext/test_uglify.py <==
# -*- coding: utf-8 -*-
"""
Use nose
`$ pip install nose`
`$ nosetests`
"""
from hyde.fs import File, Folder
from hyde.model import Expando
from hyde.generator import Generator
from hyde.site import Site

UGLIFY_SOURCE = File(__file__).parent.child_folder('uglify')
TEST_SITE = File(__file__).parent.parent.child_folder('_test')


class TestLess(object):

    def setUp(self):
        TEST_SITE.make()
        TEST_SITE.parent.child_folder(
                    'sites/test_jinja').copy_contents_to(TEST_SITE)
        JS = TEST_SITE.child_folder('content/media/js')
        JS.make()
        UGLIFY_SOURCE.copy_contents_to(JS)
        

    def tearDown(self):
        TEST_SITE.delete()

    def test_can_uglify(self):
        s = Site(TEST_SITE)
        s.config.plugins = ['hyde.ext.plugins.uglify.UglifyPlugin']
        s.config.mode = "production"
        paths = ['/usr/local/share/npm/bin/uglifyjs', '~/local/bin/uglifyjs']
        uglify = [path for path in paths if File(path).exists]
        if not uglify:
            assert False, "Cannot find the uglify executable"

        uglify = uglify[0]
        s.config.uglify = Expando(dict(app=uglify))
        source = TEST_SITE.child('content/media/js/jquery.js')
        target = File(Folder(s.config.deploy_root_path).child('media/js/jquery.js'))
        gen = Generator(s)
        gen.generate_resource_at_path(source)

        assert target.exists
        expected = File(UGLIFY_SOURCE.child('expected-jquery.js'))
        # TODO: Very fragile. Better comparison needed.
        assert target.read_all() == expected.read_all()

    def test_uglify_with_extra_options(self):
        s = Site(TEST_SITE)
        s.config.plugins = ['hyde.ext.plugins.uglify.UglifyPlugin']
        s.config.mode = "production"
        paths = ['/usr/local/share/npm/bin/uglifyjs', '~/local/bin/uglifyjs']
        uglify = [path for path in paths if File(path).exists]
        if not uglify:
            assert False, "Cannot find the uglify executable"

        uglify = uglify[0]
        s.config.uglify = Expando(dict(app=uglify, args={"nc":""}))
        source = TEST_SITE.child('content/media/js/jquery.js')
        target = File(Folder(s.config.deploy_root_path).child('media/js/jquery.js'))
        gen = Generator(s)
        gen.generate_resource_at_path(source)

        assert target.exists
        expected = File(UGLIFY_SOURCE.child('expected-jquery-nc.js'))
        # TODO: Very fragile. Better comparison needed.
        text = target.read_all()
        assert text.startswith("(function(")

    def test_no_uglify_in_dev_mode(self):
        s = Site(TEST_SITE)
        s.config.plugins = ['hyde.ext.plugins.uglify.UglifyPlugin']
        s.config.mode = "dev"
        paths = ['/usr/local/share/npm/bin/uglifyjs', '~/local/bin/uglifyjs']
        uglify = [path for path in paths if File(path).exists]
        if not uglify:
            assert False, "Cannot find the uglify executable"

        uglify = uglify[0]
        s.config.uglify = Expando(dict(app=path))
        source = TEST_SITE.child('content/media/js/jquery.js')
        target = File(Folder(s.config.deploy_root_path).child('media/js/jquery.js'))
        gen = Generator(s)
        gen.generate_resource_at_path(source)

        assert target.exists
        expected = File(UGLIFY_SOURCE.child('jquery.js'))
        # TODO: Very fragile. Better comparison needed.
        text = target.read_all()
        expected = expected.read_all()
        assert text == expected

==> hyde-0.8.3.tar.gz: hyde-0.8.3/hyde/tests/ext/test_uglify.py <==
# -*- coding: utf-8 -*-
"""
Use nose
`$ pip install nose`
`$ nosetests`
"""
from hyde.fs import File, Folder
from hyde.model import Expando
from hyde.generator import Generator
from hyde.site import Site

UGLIFY_SOURCE = File(__file__).parent.child_folder('uglify')
TEST_SITE = File(__file__).parent.parent.child_folder('_test')


class TestLess(object):

    def setUp(self):
        TEST_SITE.make()
        TEST_SITE.parent.child_folder(
                    'sites/test_jinja').copy_contents_to(TEST_SITE)
        JS = TEST_SITE.child_folder('content/media/js')
        JS.make()
        UGLIFY_SOURCE.copy_contents_to(JS)
        

    def tearDown(self):
        TEST_SITE.delete()

    def test_can_uglify(self):
        s = Site(TEST_SITE)
        s.config.plugins = ['hyde.ext.plugins.uglify.UglifyPlugin']
        s.config.mode = "production"
        paths = ['/usr/local/share/npm/bin/uglifyjs', '~/local/bin/uglifyjs',
                 '/usr/bin/uglifyjs', '~/bin/uglifyjs']
        uglify = [path for path in paths if File(path).exists]
        if not uglify:
            assert False, "Cannot find the uglify executable"

        uglify = uglify[0]
        s.config.uglify = Expando(dict(app=uglify))
        source = TEST_SITE.child('content/media/js/jquery.js')
        target = File(Folder(s.config.deploy_root_path).child('media/js/jquery.js'))
        gen = Generator(s)
        gen.generate_resource_at_path(source)

        assert target.exists
        expected = File(UGLIFY_SOURCE.child('expected-jquery.js'))
        # TODO: Very fragile. Better comparison needed.
        assert target.read_all() == expected.read_all()

    def test_uglify_with_extra_options(self):
        s = Site(TEST_SITE)
        s.config.plugins = ['hyde.ext.plugins.uglify.UglifyPlugin']
        s.config.mode = "production"
        paths = ['/usr/local/share/npm/bin/uglifyjs', '~/local/bin/uglifyjs',
                 '/usr/bin/uglifyjs', '~/bin/uglifyjs']
        uglify = [path for path in paths if File(path).exists]
        if not uglify:
            assert False, "Cannot find the uglify executable"

        uglify = uglify[0]
        s.config.uglify = Expando(dict(app=uglify, args={"nc":""}))
        source = TEST_SITE.child('content/media/js/jquery.js')
        target = File(Folder(s.config.deploy_root_path).child('media/js/jquery.js'))
        gen = Generator(s)
        gen.generate_resource_at_path(source)

        assert target.exists
        expected = File(UGLIFY_SOURCE.child('expected-jquery-nc.js'))
        # TODO: Very fragile. Better comparison needed.
        text = target.read_all()
        assert text.startswith("(function(")

    def test_no_uglify_in_dev_mode(self):
        s = Site(TEST_SITE)
        s.config.plugins = ['hyde.ext.plugins.uglify.UglifyPlugin']
        s.config.mode = "dev"
        paths = ['/usr/local/share/npm/bin/uglifyjs', '~/local/bin/uglifyjs',
                 '/usr/bin/uglifyjs', '~/bin/uglifyjs']
        uglify = [path for path in paths if File(path).exists]
        if not uglify:
            assert False, "Cannot find the uglify executable"

        uglify = uglify[0]
        s.config.uglify = Expando(dict(app=path))
        source = TEST_SITE.child('content/media/js/jquery.js')
        target = File(Folder(s.config.deploy_root_path).child('media/js/jquery.js'))
        gen = Generator(s)
        gen.generate_resource_at_path(source)

        assert target.exists
        expected = File(UGLIFY_SOURCE.child('jquery.js'))
        # TODO: Very fragile. Better comparison needed.
        text = target.read_all()
        expected = expected.read_all()
        assert text == expected
